@@ -3,7 +3,7 @@ import os
 import wandb
 
 from .filters import if_notag, if_stale
-from .utils import delete_run
+from .utils import delete_run, get_run_from_url
 
 WANDB_USER = os.environ["WANDB_ENTITY"] or False
 WANDB_KEY = os.environ["WANDB_API_KEY"] or False
